@@ -9,8 +9,8 @@ MAKO_FILESYSTEM_CHECK = False
 #是否python由提供静态文件的服务
 SERVER_STATIC_FILE = False
 
-#是否使用优化过的css，js
-MERGE_CSS_JS = True
+#是否使用原始的css，js
+ORG_CSS_JS = True
 
 #Javascript文件服务器的域名
 JS_FILE_HOST = ""
@@ -18,4 +18,5 @@ JS_FILE_HOST = ""
 #静态文件服务器的域名
 FILE_HOST = ""
 
-
+#数据库配置
+WTREE_HOST = "localhost:3306:wtree:root:password"
