@@ -4,14 +4,13 @@
 import web
 import httpserver
 import ioloop
-from web import WSGIHandler, ChunkedTransferEncoding
+from web import WSGIHandler
 
 class WSGIServer(httpserver.HTTPServer):
     """HTTP Server to work with wsgi applications."""
-    def __init__(self, port, wsgi_app , transforms=(ChunkedTransferEncoding, )):
+    def __init__(self, port, wsgi_app ):
         application = web.Application(
-            (WSGIHandler, wsgi_app),
-            transforms
+            (WSGIHandler, wsgi_app)
         )
         httpserver.HTTPServer.__init__(self, application)
         self.listen(port)
